@@ -40,4 +40,5 @@ _S(17, "PACKET_TIMESTAMP")
 _S(18, "PACKET_FANOUT")
 _S(19, "PACKET_TX_HAS_OFF")
 _S(20, "PACKET_QDISC_BYPASS")
-
+_S(21, "PACKET_ROLLOVER_STATS")
+_S(22, "PACKET_FANOUT_DATA")
