@@ -736,9 +736,7 @@ more_messages:
 	goto read_more;
 }
 
-#ifndef HAVE_LIBWRAP
-#define auditd_tcpd_check(s) ({ 0; })
-#else
+#ifdef HAVE_LIBWRAP
 int allow_severity = LOG_INFO, deny_severity = LOG_NOTICE;
 static int auditd_tcpd_check(int sock)
 {
@@ -802,6 +800,7 @@ static void auditd_tcp_listen_handler( struct ev_loop *loop,
 		return;
 	}
 
+#ifdef HAVE_LIBWRAP
 	if (use_libwrap) {
 		if (auditd_tcpd_check(afd)) {
 			shutdown(afd, SHUT_RDWR);
@@ -816,6 +815,7 @@ static void auditd_tcp_listen_handler( struct ev_loop *loop,
 			return;
 		}
 	}
+#endif
 
 	/* Verify it's coming from an authorized port.  We assume the firewall
 	 * will block attempts from unauthorized machines.  */
